@@ -7,6 +7,57 @@ import math
 import urllib
 import io
 from PIL import Image
+import os
+import sys
+#检索文件
+def searchfile(filename):
+    fileroot = ''
+    for i in sys.path:
+        try:
+            if filename in os.listdir(i):
+                fileroot = i
+        except:
+            pass
+    if fileroot == '':
+        fileroot = sys.path[-1]
+    return fileroot+'/'+filename
+
+#写入
+def set_mapboxtoken(mapboxtoken):
+    filepath = searchfile('mapboxtoken.txt')
+    f = open(filepath,mode = 'w')
+    f.write(mapboxtoken)
+    f.close()
+    print('写入成功')
+    
+#读取
+def read_mapboxtoken():
+    filepath = searchfile('mapboxtoken.txt')
+    try:
+        f = open(filepath,mode = 'r')
+        mapboxtoken = f.readline()
+        f.close()
+    except:
+        raise Exception('没有找到mapboxtoken，请先设置，详见：https://transbigdata.readthedocs.io/zh_CN/latest/plot_map.html') 
+    return mapboxtoken
+
+#写入
+def set_imgsavepath(imgsavepath):
+    filepath = searchfile('imgsavepath.txt')
+    f = open(filepath,mode = 'w')
+    f.write(imgsavepath)
+    f.close()
+    print('写入成功')
+#读取
+def read_imgsavepath():
+    filepath = searchfile('imgsavepath.txt')
+    try:
+        f = open(filepath,mode = 'r')
+        imgsavepath = f.readline()
+        f.close()
+    except:
+        raise Exception('没有找到地图底图存放路径，请先设置，详见：https://transbigdata.readthedocs.io/zh_CN/latest/plot_map.html') 
+    return imgsavepath
 
 def deg2num(lat_deg, lon_deg, zoom):
     lat_rad = math.radians(lat_deg)
@@ -22,9 +73,7 @@ def num2deg(xtile, ytile, zoom):
     lat_deg = math.degrees(lat_rad)
     return (lat_deg, lon_deg)
 
-
-
-def getImageCluster( lon_deg,lat_deg,   delta_long, delta_lat,zoom,printlog,imgsavepath,style = 4,apikey = '',access_token = '',styleid = 'light'):
+def getImageCluster( lon_deg,lat_deg, delta_long, delta_lat,zoom,printlog,imgsavepath,style = 4,apikey = '',access_token = '',styleid = 'light'):
     '''
     apikey - openstreetmap token
     access_token - mapbox token
@@ -36,11 +85,9 @@ def getImageCluster( lon_deg,lat_deg,   delta_long, delta_lat,zoom,printlog,imgs
     if style == 3:
         smurl = r'http://c.tile.stamen.com/watercolor/{0}/{1}/{2}.png'
     if (style == 4 )|(style == 'light' ):
-        access_token = 'pk.eyJ1IjoibmkxbzEiLCJhIjoiY2pldGxtNGhyMGtnNTJ3cGU4Ymt6c3Z3ciJ9.pqgh09z8NCQfONAuukSUPA'
-        styleid = 'cjrewwj3l2dwt2tptkiu09scd'
+        styleid = 'ckwfx658z4dpb14ocnz6tky9d'
         smurl = r'https://api.mapbox.com/styles/v1/ni1o1/'+styleid+r'/tiles/256/{0}/{1}/{2}?&access_token='+access_token
     if (style == 5 )|(style == 'dark' ):
-        access_token = 'pk.eyJ1IjoibmkxbzEiLCJhIjoiY2pldGxtNGhyMGtnNTJ3cGU4Ymt6c3Z3ciJ9.pqgh09z8NCQfONAuukSUPA'
         styleid = 'cjetnd20i1vbi2qqxbh0by7p8'
         smurl = r'https://api.mapbox.com/styles/v1/ni1o1/'+styleid+r'/tiles/256/{0}/{1}/{2}?&access_token='+access_token
     else:
@@ -118,7 +165,7 @@ def getImageCluster( lon_deg,lat_deg,   delta_long, delta_lat,zoom,printlog,imgs
     return Cluster
 
     
-def plot_map(plt,bounds,zoom,style=4,imgsavepath = r'/Users/yuqing/Nutstore Files/我的坚果云/python_new/',printlog = False,apikey = '',access_token = '',styleid = 'light'):
+def plot_map(plt,bounds,zoom,style=4,printlog = False,apikey = '',styleid = 'light'):
     '''
     bounds -- Set your plotting boundary [lon1,lat1,lon2,lat2] (wgs1984)
     zoom -- The zoom level of the map
@@ -126,12 +173,14 @@ def plot_map(plt,bounds,zoom,style=4,imgsavepath = r'/Users/yuqing/Nutstore File
     styleid -- if style is set as 7(from mapbox), you can change the styleid here, "dark" or "light" or your own style
     imgsavepath -- Path to save the tile map so that you don't have to download again
     '''
+    access_token = read_mapboxtoken()
+    imgsavepath = read_imgsavepath()
     try:
         import os
         os.listdir(imgsavepath)
     except:
         print('imgsavepath do not exist, your tile map will not save')
-    lon1= bounds[0]
+    lon1 = bounds[0]
     lat1 =  bounds[1]
     lon2 =  bounds[2]
     lat2 =  bounds[3]
@@ -214,4 +263,5 @@ def plotscale(ax,bounds,textcolor = 'k',textsize = 8,compasssize = 1,accuracy =
     [Polygon([[alon,alat],[alon,alat+deltaLon],[alon+1/2*deltaLon,alat-1/2*deltaLon]]),
     Polygon([[alon,alat],[alon,alat+deltaLon],[alon-1/2*deltaLon,alat-1/2*deltaLon]])]})
     compass.plot(ax= ax, edgecolor= (0,0,0,1),facecolor = compass['color'],lw = 0.6,**kwargs)
-    ax.text(alon,alat+deltaLon,'N',color = textcolor,fontsize = textsize,ha = 'center',va = 'bottom')
\ No newline at end of file
+    ax.text(alon,alat+deltaLon,'N',color = textcolor,fontsize = textsize,ha = 'center',va = 'bottom')
+
